@@ -57,9 +57,9 @@ RecursiveScanJob::RecursiveScanJob(const QString& dbName, QObject* parent)
 
 bool RecursiveScanJob::doKill()
 {
-#if 0 //KDE5PORT
+#if QT_VERSION >= 0x050500
     foreach(ScanJob* job, m_jobs)
-        ThreadWeaver::Weaver::instance()->dequeue(job);
+        TM::threadPool()->cancel(job);
 #endif
     return true;
 }
@@ -110,7 +110,8 @@ int TM::scanRecursive(const QStringList& filePaths, const QString& dbName)
 #else
     KJob* metaJob=0;
 #endif
-    askAuthorInfoIfEmpty();
+    if (!askAuthorInfoIfEmpty())
+        return 0;
 
     QVector<ScanJob*> result;
     int i=filePaths.size();
